Reteno class

Constructors

Reteno()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

diagnose() Future<List<String>>
Returns integration diagnostics codes from native SDK/plugin.
getInitialNotification() Future
Retrieves the initial notification when app is opened from terminated state by notification.
getRecommendations({required String recomenedationVariantId, required List<String> productIds, String? categoryId, List<RetenoRecomendationFilter>? filters, List<String>? fields}) Future<List<RetenoRecommendation>>
Get product recommendations
getRecommendationsJson({required String recomenedationVariantId, required List<String> productIds, String? categoryId, List<RetenoRecomendationFilter>? filters, List<String>? fields}) Future<Map<String, dynamic>>
Get recommendations as JSON
initialize({required String accessKey, RetenoInitOptions options = const RetenoInitOptions(), Future<String?> customDeviceId()?}) Future<void>
Canonical initialization entrypoint.
initWith({required String accessKey, bool isPausedInAppMessages = false, bool isDebug = false, LifecycleTrackingOptions? lifecycleTrackingOptions, Future<String?> customDeviceId()?, RetenoDeviceTokenHandlingMode deviceTokenHandlingMode = RetenoDeviceTokenHandlingMode.automatic, RetenoDefaultNotificationChannelConfig? defaultNotificationChannelConfig}) Future<void>
Backward-compatible alias for initialize.
logEcommerceEvent(RetenoEcommerceEvent event) Future<void>
Reteno's e-commerce activity tracking helps to learn about the customer journey and use this data in your analytics. The list of supported events: supported events:
logEvent({required RetenoCustomEvent event}) Future<bool>
Track custom events
logEventJson({required String eventTypeKey, required Map<String, String> jsonParameters, DateTime? dateOccurred, bool forcePush = false}) Future<bool>
Convenience helper to log event with JSON parameters map.
logRecommendationsEvent(RetenoRecomEvents events) Future<void>
Log recommendations events RetenoRecomEvents - recommendation event to be logged
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseInAppMessages(bool isPaused) Future<void>
Pause or resume in-app messages
requestPushPermission({bool provisional = false}) Future<bool>
Requests push permission on iOS and Android 13+ and syncs status to backend.
setAnomymousUserAttributes({required AnonymousUserAttributes anonymousUserAttributes}) Future<bool>
Update Anonymous User attributes
setUserAttributes({required String userExternalId, RetenoUser? user}) Future<bool>
Update User attributes
toString() String
A string representation of this object.
inherited
updatePushPermissionStatus() Future<bool>
Updates status of POST_NOTIFICATIONS permission and pushes it to backend if status was changed.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

appInbox → AppInbox
Reteno AppInbox instance.
no setter
onCorePushAction Stream<RetenoUserNotificationAction>
Cross-platform core stream alias for push action events.
no setter
onCorePushClicked Stream<Map<String, dynamic>>
Cross-platform core stream alias for push clicked events.
no setter
onCorePushReceived Stream<Map<String, dynamic>>
Cross-platform core stream alias for push received events.
no setter
onInAppMessageStatusChanged Stream<InAppMessageStatus>
A static getter that provides a Stream of in-app message status changes. You can detect In-App presenting status where needed. InAppShouldBeDisplayed - called when the in-app should be displayed InAppIsDisplayed - called when the in-app is displayed InAppShouldBeClosed - called when the in-app should be closed InAppIsClosed - called when the in-app is closed InAppReceivedError - called when the in-app can't be shown for some reason
no setter
onRetenoCustomNotificationReceived Stream<Map<String, dynamic>>
Platform-specific stream for custom push payload callbacks (currently Android SDK event source).
no setter
onRetenoInAppCustomDataReceived Stream<RetenoInAppCustomData>
Platform-specific stream for in-app custom data callbacks (currently Android SDK event source).
no setter
onRetenoNotificationClicked Stream<Map<String, dynamic>>
A static getter that provides a Stream of notifications clicked by the user in foreground and background states.
no setter
onRetenoNotificationDeleted Stream<Map<String, dynamic>>
Platform-specific stream for push dismissed (currently Android SDK event source).
no setter
onRetenoNotificationReceived Stream<Map<String, dynamic>>
A static getter that provides a Stream of notifications received when application is in foreground.
no setter
onUserNotificationAction Stream<RetenoUserNotificationAction>
A static getter that provides a Stream of user notification actions. This Stream emits RetenoUserNotificationAction object RetenoUserNotificationAction
no setter