onRetenoNotificationReceived property

Stream<Map<String, dynamic>> get onRetenoNotificationReceived

A static getter that provides a Stream of notifications received when application is in foreground.

This Stream emits Map objects containing notification data in the form of key-value pairs, where keys are strings and values are dynamic types. You can use this stream to listen for notifications as they are received by the Reteno plugin and react to them in your Flutter application.

Example usage:

Reteno.onRetenoNotificationReceived.listen((notification) {
  // Handle the received notification here
  print("Received notification: $notification");
});

Implementation

static Stream<Map<String, dynamic>> get onRetenoNotificationReceived => _platform.onRetenoNotificationReceived.stream;