RetenoDefaultNotificationChannelConfig class

Constructors

RetenoDefaultNotificationChannelConfig({String? name, String? description, bool? showBadge, bool? lightsEnabled, bool? vibrationEnabled})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
lightsEnabled bool?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBadge bool?
final
vibrationEnabled bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited