RetenoEcommerceItem class

Constructors

RetenoEcommerceItem({required String externalItemId, required String name, required String category, required double quantity, required double cost, required String url, String? imageUrl, String? description})
const

Properties

category String
final
cost double
final
description String?
final
externalItemId String
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
final
name String
final
quantity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited