RetenoEcommerceProductCategoryViewed class

Track a product category a user is viewing for triggers like Website visit with a category view and Website visit without a category view.

Inheritance

Properties

category RetenoEcommerceCategory
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited