RetenoEcommerceProductViewed class

Track a product card a user is viewing to rank items / categories and send triggers for abandoned browses.

Inheritance

Constructors

RetenoEcommerceProductViewed({required RetenoEcommerceProduct product, String? currency})

Properties

currency String?
Currency in ISO 4217 format. Supported currencies: USD, EUR, UAH. If is not set then org's default is used
final
hashCode int
The hash code for this object.
no setterinherited
product RetenoEcommerceProduct
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited