RetenoInAppCustomData class

Constructors

RetenoInAppCustomData({String? url, required String source, required String inAppId, required Map<String, String> data})

Properties

data Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
inAppId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited