RetenoNotificationGroupingRule class

Android push notification grouping configuration.

The rule is persisted by the native plugin so it can be applied when a push arrives while the Flutter engine is not running.

Constructors

RetenoNotificationGroupingRule.byPayloadKey(String payloadKey, {String? fallbackGroupId})
Uses the value stored under payloadKey in the push payload as group ID.
const
RetenoNotificationGroupingRule.constant(String groupId)
Uses the same groupId for every Reteno push notification.
const

Properties

fallbackGroupId String?
final
hashCode int
The hash code for this object.
no setterinherited
payloadKey String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited