RetenoNotificationGroupingRule.byPayloadKey constructor

const RetenoNotificationGroupingRule.byPayloadKey(
  1. String payloadKey, {
  2. String? fallbackGroupId,
})

Uses the value stored under payloadKey in the push payload as group ID.

fallbackGroupId is used when the payload does not contain a non-empty value for payloadKey. When it is null, that notification is not assigned to a group.

Implementation

const RetenoNotificationGroupingRule.byPayloadKey(
  String payloadKey, {
  String? fallbackGroupId,
}) : this._(
        payloadKey: payloadKey,
        fallbackGroupId: fallbackGroupId,
      );