RetenoRecommendation class

Constructors

RetenoRecommendation({required String productId, double? price, String? name, String? description, String? imageUrl, List<String>? category, List<String>? categoryAncestor, List<String>? categoryLayout, List<String>? categoryParent, String? dateCreatedAs, String? dateCreatedEs, String? dateModifiedAs, String? itemGroup, String? nameKeyword, String? productIdAlt, String? tagsAllCategoryNames, String? tagsBestseller, String? tagsCashback, String? tagsCategoryBestseller, String? tagsCredit, String? tagsDelivery, String? tagsDescriptionPriceRange, String? tagsDiscount, String? tagsHasPurchases21Days, String? tagsIsBestseller, String? tagsIsBestsellerByCategories, String? tagsItemGroupId, String? tagsNumPurchases21Days, String? tagsOldPrice, String? tagsOldprice, String? tagsPriceRange, String? tagsRating, String? tagsSale, String? url})

Properties

category List<String>?
final
categoryAncestor List<String>?
final
categoryLayout List<String>?
final
categoryParent List<String>?
final
dateCreatedAs String?
final
dateCreatedEs String?
final
dateModifiedAs String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
final
itemGroup String?
final
name String?
final
nameKeyword String?
final
price double?
final
productId String
final
productIdAlt String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagsAllCategoryNames String?
final
tagsBestseller String?
final
tagsCashback String?
final
tagsCategoryBestseller String?
final
tagsCredit String?
final
tagsDelivery String?
final
tagsDescriptionPriceRange String?
final
tagsDiscount String?
final
tagsHasPurchases21Days String?
final
tagsIsBestseller String?
final
tagsIsBestsellerByCategories String?
final
tagsItemGroupId String?
final
tagsNumPurchases21Days String?
final
tagsOldPrice String?
final
tagsOldprice String?
final
tagsPriceRange String?
final
tagsRating String?
final
tagsSale String?
final
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited