Reteno class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
diagnose ()
→ Future <List <String > >
Returns integration diagnostics codes from native SDK/plugin.
getInitialNotification ()
→ Future
Retrieves the initial notification when app is opened from terminated state by notification.
getRecommendations ({required String recomenedationVariantId , required List <String > productIds , String ? categoryId , List <RetenoRecomendationFilter > ? filters , List <String > ? fields })
→ Future <List <RetenoRecommendation > >
Get product recommendations
getRecommendationsJson ({required String recomenedationVariantId , required List <String > productIds , String ? categoryId , List <RetenoRecomendationFilter > ? filters , List <String > ? fields })
→ Future <Map <String , dynamic > >
Get recommendations as JSON
initialize ({required String accessKey , RetenoInitOptions options = const RetenoInitOptions() , Future <String ? > customDeviceId ()? })
→ Future <void >
Canonical initialization entrypoint.
initWith ({required String accessKey , bool isPausedInAppMessages = false , bool isDebug = false , LifecycleTrackingOptions ? lifecycleTrackingOptions , Future <String ? > customDeviceId ()?, RetenoDeviceTokenHandlingMode deviceTokenHandlingMode = RetenoDeviceTokenHandlingMode.automatic , RetenoDefaultNotificationChannelConfig ? defaultNotificationChannelConfig })
→ Future <void >
Backward-compatible alias for initialize .
logEcommerceEvent (RetenoEcommerceEvent event )
→ Future <void >
Reteno's e-commerce activity tracking helps to learn about the customer journey and use this data in your analytics.
The list of supported events:
supported events:
logEvent ({required RetenoCustomEvent event })
→ Future <bool >
Track custom events
logEventJson ({required String eventTypeKey , required Map <String , String > jsonParameters , DateTime ? dateOccurred , bool forcePush = false })
→ Future <bool >
Convenience helper to log event with JSON parameters map.
logRecommendationsEvent (RetenoRecomEvents events )
→ Future <void >
Log recommendations events
RetenoRecomEvents - recommendation event to be logged
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseInAppMessages (bool isPaused )
→ Future <void >
Pause or resume in-app messages
requestPushPermission ({bool provisional = false })
→ Future <bool >
Requests push permission on iOS and Android 13+ and syncs status to backend.
setAnomymousUserAttributes ({required AnonymousUserAttributes anonymousUserAttributes })
→ Future <bool >
Update Anonymous User attributes
setUserAttributes ({required String userExternalId , RetenoUser ? user })
→ Future <bool >
Update User attributes
toString ()
→ String
A string representation of this object.
inherited
updatePushPermissionStatus ()
→ Future <bool >
Updates status of POST_NOTIFICATIONS permission and pushes it to backend if status was changed.