RetenoInitOptions class
Constructors
- RetenoInitOptions({bool isPausedInAppMessages = false, bool isDebug = false, LifecycleTrackingOptions? lifecycleTrackingOptions, RetenoDeviceTokenHandlingMode deviceTokenHandlingMode = RetenoDeviceTokenHandlingMode.automatic, RetenoDefaultNotificationChannelConfig? defaultNotificationChannelConfig})
-
const
Properties
- defaultNotificationChannelConfig → RetenoDefaultNotificationChannelConfig?
-
final
- deviceTokenHandlingMode → RetenoDeviceTokenHandlingMode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDebug → bool
-
final
- isPausedInAppMessages → bool
-
final
- lifecycleTrackingOptions → LifecycleTrackingOptions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited